More information
----------------

Get more information at https://omegaml.github.io/omegaml/

Towards Data Science recently published an article on omega-ml:
https://towardsdatascience.com/omega-ml-deploying-data-machine-learning-pipelines-the-easy-way-a3d281569666

In addition omega-ml provides an easy-to-use extensions API to support any kind of models,
compute cluster, database and data source.

*Commercial Edition*

omega-ml Commercial Edition provides security on every level and is ready made
for Kubernetes deployment. It is licensed separately for on-premise, private or
hybrid cloud. Sign up at https://omegaml.io

